@@ -6,7 +6,7 @@ const monorepo = new pdk_projen.NxMonorepoProject({
   name: 'monorepo',
 });
 
-new pdk_projen.PdkPipelinePyProject({
+new pdk_projen.PDKPipelinePyProject({
   authorEmail: '',
   authorName: '',
   cdkVersion: '2.0.0',
